@@ -8,6 +8,8 @@
 #include "caf/detail/print.hpp"
 #include "caf/string_algorithms.hpp"
 
+#include <fstream>
+
 namespace {
 
 static constexpr const char class_name[] = "caf::json_reader";
@@ -50,23 +52,24 @@ std::string type_clash(caf::json_reader::position want,
 
 std::string type_clash(caf::string_view want,
                        const caf::detail::json::value& got) {
-  using namespace caf::literals;
+  using namespace std::literals;
   using caf::detail::json::value;
   switch (got.data.index()) {
     case value::integer_index:
-      return type_clash(want, "json::integer"_sv);
+    case value::unsigned_index:
+      return type_clash(want, "json::integer"sv);
     case value::double_index:
-      return type_clash(want, "json::real"_sv);
+      return type_clash(want, "json::real"sv);
     case value::bool_index:
-      return type_clash(want, "json::boolean"_sv);
+      return type_clash(want, "json::boolean"sv);
     case value::string_index:
-      return type_clash(want, "json::string"_sv);
+      return type_clash(want, "json::string"sv);
     case value::array_index:
-      return type_clash(want, "json::array"_sv);
+      return type_clash(want, "json::array"sv);
     case value::object_index:
-      return type_clash(want, "json::object"_sv);
+      return type_clash(want, "json::object"sv);
     default:
-      return type_clash(want, "json::null"_sv);
+      return type_clash(want, "json::null"sv);
   }
 }
 
@@ -102,18 +105,18 @@ caf::string_view field_type(const caf::detail::json::object* obj,
 
 #define INVALID_AND_PAST_THE_END_CASES                                         \
   case position::invalid:                                                      \
-    emplace_error(sec::runtime_error, class_name, fn,                          \
+    emplace_error(sec::runtime_error, class_name, fn, current_field_name(),    \
                   "found an invalid position");                                \
     return false;                                                              \
   case position::past_the_end:                                                 \
-    emplace_error(sec::runtime_error, class_name, fn,                          \
+    emplace_error(sec::runtime_error, class_name, fn, current_field_name(),    \
                   "tried reading past the end");                               \
     return false;
 
 #define SCOPE(expected_position)                                               \
   if (auto got = pos(); got != expected_position) {                            \
     emplace_error(sec::runtime_error, class_name, __func__,                    \
-                  type_clash(expected_position, got));                         \
+                  current_field_name(), type_clash(expected_position, got));   \
     return false;                                                              \
   }
 
@@ -122,14 +125,17 @@ namespace caf {
 // -- constructors, destructors, and assignment operators ----------------------
 
 json_reader::json_reader() : super() {
+  field_.reserve(8);
   has_human_readable_format_ = true;
 }
 
 json_reader::json_reader(actor_system& sys) : super(sys) {
+  field_.reserve(8);
   has_human_readable_format_ = true;
 }
 
 json_reader::json_reader(execution_unit* ctx) : super(ctx) {
+  field_.reserve(8);
   has_human_readable_format_ = true;
 }
 
@@ -142,19 +148,41 @@ json_reader::~json_reader() {
 bool json_reader::load(string_view json_text) {
   reset();
   string_parser_state ps{json_text.begin(), json_text.end()};
+  root_ = detail::json::parse_shallow(ps, &buf_);
+  if (ps.code != pec::success) {
+    set_error(make_error(ps));
+    st_ = nullptr;
+    return false;
+  }
+  err_.reset();
+  detail::monotonic_buffer_resource::allocator<stack_type> alloc{&buf_};
+  st_ = new (alloc.allocate(1)) stack_type(stack_allocator{&buf_});
+  st_->reserve(16);
+  st_->emplace_back(root_);
+  return true;
+}
+
+bool json_reader::load_file(const char* path) {
+  using iterator_t = std::istreambuf_iterator<char>;
+  reset();
+  std::ifstream input{path};
+  if (!input.is_open()) {
+    emplace_error(sec::cannot_open_file);
+    return false;
+  }
+  detail::json::file_parser_state ps{iterator_t{input}, iterator_t{}};
   root_ = detail::json::parse(ps, &buf_);
   if (ps.code != pec::success) {
     set_error(make_error(ps));
     st_ = nullptr;
     return false;
-  } else {
-    err_.reset();
-    detail::monotonic_buffer_resource::allocator<stack_type> alloc{&buf_};
-    st_ = new (alloc.allocate(1)) stack_type(stack_allocator{&buf_});
-    st_->reserve(16);
-    st_->emplace_back(root_);
-    return true;
   }
+  err_.reset();
+  detail::monotonic_buffer_resource::allocator<stack_type> alloc{&buf_};
+  st_ = new (alloc.allocate(1)) stack_type(stack_allocator{&buf_});
+  st_->reserve(16);
+  st_->emplace_back(root_);
+  return true;
 }
 
 void json_reader::revert() {
@@ -163,6 +191,7 @@ void json_reader::revert() {
     err_.reset();
     st_->clear();
     st_->emplace_back(root_);
+    field_.clear();
   }
 }
 
@@ -170,6 +199,7 @@ void json_reader::reset() {
   buf_.reclaim();
   st_ = nullptr;
   err_.reset();
+  field_.clear();
 }
 
 // -- interface functions ------------------------------------------------------
@@ -177,13 +207,14 @@ void json_reader::reset() {
 bool json_reader::fetch_next_object_type(type_id_t& type) {
   string_view type_name;
   if (fetch_next_object_name(type_name)) {
-    if (auto id = query_type_id(type_name); id != invalid_type_id) {
+    if (auto id = (*mapper_)(type_name); id != invalid_type_id) {
       type = id;
       return true;
     } else {
       std::string what = "no type ID available for @type: ";
       what.insert(what.end(), type_name.begin(), type_name.end());
-      emplace_error(sec::runtime_error, class_name, __func__, std::move(what));
+      emplace_error(sec::runtime_error, class_name, __func__,
+                    current_field_name(), std::move(what));
       return false;
     }
   } else {
@@ -195,23 +226,24 @@ bool json_reader::fetch_next_object_name(string_view& type_name) {
   FN_DECL;
   return consume<false>(fn, [this, &type_name](const detail::json::value& val) {
     if (val.data.index() == detail::json::value::object_index) {
-      auto& obj = get<detail::json::object>(val.data);
+      auto& obj = std::get<detail::json::object>(val.data);
       if (auto mem_ptr = find_member(&obj, "@type")) {
         if (mem_ptr->val->data.index() == detail::json::value::string_index) {
           type_name = std::get<string_view>(mem_ptr->val->data);
           return true;
         } else {
           emplace_error(sec::runtime_error, class_name, fn,
+                        current_field_name(),
                         "expected a string argument to @type");
           return false;
         }
       } else {
-        emplace_error(sec::runtime_error, class_name, fn,
+        emplace_error(sec::runtime_error, class_name, fn, current_field_name(),
                       "found no @type member");
         return false;
       }
     } else {
-      emplace_error(sec::runtime_error, class_name, fn,
+      emplace_error(sec::runtime_error, class_name, fn, current_field_name(),
                     type_clash("json::object", val));
       return false;
     }
@@ -222,10 +254,10 @@ bool json_reader::begin_object(type_id_t, string_view) {
   FN_DECL;
   return consume<false>(fn, [this](const detail::json::value& val) {
     if (val.data.index() == detail::json::value::object_index) {
-      push(&get<detail::json::object>(val.data));
+      push(&std::get<detail::json::object>(val.data));
       return true;
     } else {
-      emplace_error(sec::runtime_error, class_name, fn,
+      emplace_error(sec::runtime_error, class_name, fn, current_field_name(),
                     type_clash("json::object", val));
       return false;
     }
@@ -247,6 +279,7 @@ bool json_reader::end_object() {
       return true;
     default:
       emplace_error(sec::runtime_error, class_name, __func__,
+                    current_field_name(),
                     type_clash("json::value or json::array", current_pos));
       return false;
   }
@@ -254,18 +287,20 @@ bool json_reader::end_object() {
 
 bool json_reader::begin_field(string_view name) {
   SCOPE(position::object);
+  field_.push_back(name);
   if (auto member = find_member(top<position::object>(), name)) {
     push(member->val);
     return true;
   } else {
     emplace_error(sec::runtime_error, class_name, __func__,
-                  "no such field: " + to_string(name));
+                  mandatory_field_missing_str(name));
     return false;
   }
 }
 
 bool json_reader::begin_field(string_view name, bool& is_present) {
   SCOPE(position::object);
+  field_.push_back(name);
   if (auto member = find_member(top<position::object>(), name);
       member != nullptr
       && member->val->data.index() != detail::json::value::null_index) {
@@ -277,15 +312,15 @@ bool json_reader::begin_field(string_view name, bool& is_present) {
   return true;
 }
 
-bool json_reader::begin_field(string_view name, span<const type_id_t> types,
-                              size_t& index) {
+bool json_reader::begin_field(string_view name,
+                              span<const type_id_t> types, size_t& index) {
   bool is_present = false;
   if (begin_field(name, is_present, types, index)) {
     if (is_present) {
       return true;
     } else {
       emplace_error(sec::runtime_error, class_name, __func__,
-                    "mandatory field missing");
+                    mandatory_field_missing_str(name));
       return false;
     }
   } else {
@@ -296,11 +331,12 @@ bool json_reader::begin_field(string_view name, span<const type_id_t> types,
 bool json_reader::begin_field(string_view name, bool& is_present,
                               span<const type_id_t> types, size_t& index) {
   SCOPE(position::object);
+  field_.push_back(name);
   if (auto member = find_member(top<position::object>(), name);
       member != nullptr
       && member->val->data.index() != detail::json::value::null_index) {
     auto ft = field_type(top<position::object>(), name, field_type_suffix_);
-    if (auto id = query_type_id(ft); id != invalid_type_id) {
+    if (auto id = (*mapper_)(ft); id != invalid_type_id) {
       if (auto i = std::find(types.begin(), types.end(), id);
           i != types.end()) {
         index = static_cast<size_t>(std::distance(types.begin(), i));
@@ -316,7 +352,10 @@ bool json_reader::begin_field(string_view name, bool& is_present,
 
 bool json_reader::end_field() {
   SCOPE(position::object);
-  // Note: no pop() here, because the value(s) were already consumed.
+  // Note: no pop() here, because the value(s) were already consumed. Only
+  //       update the field_ for debugging.
+  if (!field_.empty())
+    field_.pop_back();
   return true;
 }
 
@@ -332,7 +371,7 @@ bool json_reader::begin_tuple(size_t size) {
       msg += ", got a list of size ";
       detail::print(msg, list_size);
       emplace_error(sec::conversion_failed, class_name, __func__,
-                    std::move(msg));
+                    current_field_name(), std::move(msg));
       return false;
     }
   } else {
@@ -368,12 +407,12 @@ bool json_reader::begin_sequence(size_t& size) {
   FN_DECL;
   return consume<false>(fn, [this, &size](const detail::json::value& val) {
     if (val.data.index() == detail::json::value::array_index) {
-      auto& ls = get<detail::json::array>(val.data);
+      auto& ls = std::get<detail::json::array>(val.data);
       size = ls.size();
       push(sequence{ls.begin(), ls.end()});
       return true;
     } else {
-      emplace_error(sec::runtime_error, class_name, fn,
+      emplace_error(sec::runtime_error, class_name, fn, current_field_name(),
                     type_clash("json::array", val));
       return false;
     }
@@ -399,13 +438,13 @@ bool json_reader::begin_associative_array(size_t& size) {
   FN_DECL;
   return consume<false>(fn, [this, &size](const detail::json::value& val) {
     if (val.data.index() == detail::json::value::object_index) {
-      auto* obj = std::addressof(get<detail::json::object>(val.data));
+      auto* obj = std::addressof(std::get<detail::json::object>(val.data));
       pop();
       size = obj->size();
       push(members{obj->begin(), obj->end()});
       return true;
     } else {
-      emplace_error(sec::runtime_error, class_name, fn,
+      emplace_error(sec::runtime_error, class_name, fn, current_field_name(),
                     type_clash("json::object", val));
       return false;
     }
@@ -441,7 +480,7 @@ bool json_reader::value(bool& x) {
       x = std::get<bool>(val.data);
       return true;
     } else {
-      emplace_error(sec::runtime_error, class_name, fn,
+      emplace_error(sec::runtime_error, class_name, fn, current_field_name(),
                     type_clash("json::boolean", val));
       return false;
     }
@@ -481,7 +520,7 @@ bool json_reader::consume(const char* fn, F f) {
         return false;
       }
     default:
-      emplace_error(sec::runtime_error, class_name, fn,
+      emplace_error(sec::runtime_error, class_name, fn, current_field_name(),
                     type_clash("json::value", current_pos));
       return false;
   }
@@ -496,13 +535,21 @@ bool json_reader::integer(T& x) {
       if (detail::bounds_checker<T>::check(i64)) {
         x = static_cast<T>(i64);
         return true;
-      } else {
-        emplace_error(sec::runtime_error, class_name, fn,
-                      "integer out of bounds");
-        return false;
       }
-    } else {
       emplace_error(sec::runtime_error, class_name, fn,
+                    "signed integer out of bounds");
+      return false;
+    } else if (val.data.index() == detail::json::value::unsigned_index) {
+      auto u64 = std::get<uint64_t>(val.data);
+      if (detail::bounds_checker<T>::check(u64)) {
+        x = static_cast<T>(u64);
+        return true;
+      }
+      emplace_error(sec::runtime_error, class_name, fn,
+                    "unsigned integer out of bounds");
+      return false;
+    } else {
+      emplace_error(sec::runtime_error, class_name, fn, current_field_name(),
                     type_clash("json::integer", val));
       return false;
     }
@@ -554,13 +601,20 @@ bool json_reader::value(float& x) {
 bool json_reader::value(double& x) {
   FN_DECL;
   return consume<true>(fn, [this, &x](const detail::json::value& val) {
-    if (val.data.index() == detail::json::value::double_index) {
-      x = std::get<double>(val.data);
-      return true;
-    } else {
-      emplace_error(sec::runtime_error, class_name, fn,
-                    type_clash("json::real", val));
-      return false;
+    switch (val.data.index()) {
+      case detail::json::value::double_index:
+        x = std::get<double>(val.data);
+        return true;
+      case detail::json::value::integer_index:
+        x = std::get<int64_t>(val.data);
+        return true;
+      case detail::json::value::unsigned_index:
+        x = std::get<uint64_t>(val.data);
+        return true;
+      default:
+        emplace_error(sec::runtime_error, class_name, fn, current_field_name(),
+                      type_clash("json::real", val));
+        return false;
     }
   });
 }
@@ -582,7 +636,7 @@ bool json_reader::value(std::string& x) {
       detail::print_unescaped(x, std::get<string_view>(val.data));
       return true;
     } else {
-      emplace_error(sec::runtime_error, class_name, fn,
+      emplace_error(sec::runtime_error, class_name, fn, current_field_name(),
                     type_clash("json::string", val));
       return false;
     }
@@ -616,4 +670,27 @@ json_reader::position json_reader::pos() const noexcept {
     return static_cast<position>(st_->back().index());
 }
 
+void json_reader::append_current_field_name(std::string& result) {
+  result += "ROOT";
+  for (auto& key : field_) {
+    result += '.';
+    result.insert(result.end(), key.begin(), key.end());
+  }
+}
+
+std::string json_reader::current_field_name() {
+  std::string result;
+  append_current_field_name(result);
+  return result;
+}
+
+std::string json_reader::mandatory_field_missing_str(string_view name) {
+  std::string msg = "mandatory field '";
+  append_current_field_name(msg);
+  msg += '.';
+  msg.insert(msg.end(), name.begin(), name.end());
+  msg += "' missing";
+  return msg;
+}
+
 } // namespace caf
