@@ -118,7 +118,7 @@ public:
         return *this;
     }
 
-    ~Chunk() = default;
+    ~Chunk();
 
     Offset offset() const { return _offset; }
     Offset endOffset() const { return _offset + size(); }
@@ -189,8 +189,6 @@ protected:
     // only from chain so that it can track any changes.
     friend class Chain;
 
-    void trim(const Offset& o);
-
     // Update offset for current chunk and all others linked from it.
     void setOffset(Offset o) {
         auto c = this;
