@@ -59,6 +59,8 @@ Reporter::Reporter(bool arg_abort_on_scripting_errors)
 	weird_sampling_duration = 0;
 	weird_sampling_threshold = 0;
 
+	ignore_deprecations = false;
+
 	syslog_open = false;
 	}
 
@@ -86,7 +88,7 @@ void Reporter::InitOptions()
 			auto k = wle.GetHashKey();
 			auto index = wl_val->RecreateIndex(*k);
 			std::string key = index->Idx(0)->AsString()->CheckString();
-			set->emplace(move(key));
+			set->emplace(std::move(key));
 			}
 	};
 
@@ -532,6 +534,21 @@ void Reporter::Weird(const IPAddr& orig, const IPAddr& resp, const char* name, c
 	            "%s", name);
 	}
 
+void Reporter::Deprecation(std::string_view msg, const detail::Location* loc1,
+                           const detail::Location* loc2)
+	{
+	if ( ignore_deprecations )
+		return;
+
+	if ( loc1 || loc2 )
+		PushLocation(loc1, loc2);
+
+	Warning("%s", msg.data());
+
+	if ( loc1 || loc2 )
+		PopLocation();
+	}
+
 void Reporter::DoLog(const char* prefix, EventHandlerPtr event, FILE* out, Connection* conn,
                      ValPList* addl, bool location, bool time, const char* postfix, const char* fmt,
                      va_list ap)
