@@ -77,7 +77,10 @@ public:
 	void Done() override;
 	void DeliverStream(int len, const u_char* data, bool orig) override;
 
-	static analyzer::Analyzer* Instantiate(Connection* conn) { return new POP3_Analyzer(conn); }
+	static analyzer::Analyzer* Instantiate(Connection* conn)
+		{
+		return new POP3_Analyzer(conn);
+		}
 
 protected:
 	int masterState;
