@@ -350,7 +350,7 @@ ExprPtr Expr::ReduceToConditional(Reducer* c, StmtPtr& red_stmt)
 					return Reduce(c, red_stmt);
 				}
 
-			if ( ! op1->IsReduced(c) || ! op2->IsReduced(c) )
+			if ( ! op1->IsReduced(c) || ! op2->IsSingleton(c) )
 				{
 				auto red2_stmt = ReduceToSingletons(c);
 				auto res = ReduceToConditional(c, red_stmt);
@@ -2415,8 +2415,8 @@ StmtPtr CallExpr::ReduceToSingletons(Reducer* c)
 
 ExprPtr LambdaExpr::Duplicate()
 	{
-	auto ingr = std::make_unique<function_ingredients>(*ingredients);
-	ingr->body = ingr->body->Duplicate();
+	auto ingr = std::make_unique<FunctionIngredients>(*ingredients);
+	ingr->SetBody(ingr->Body()->Duplicate());
 	return SetSucc(new LambdaExpr(std::move(ingr), outer_ids));
 	}
 
