@@ -1,7 +1,7 @@
 
 #pragma once
 
-#include <plugin/Plugin.h>
+#include <zeek/plugin/Plugin.h>
 
 namespace btest::plugin::Demo_Hooks
 	{
